import java.net.InetAddress;
import java.net.Socket;
import java.net.URL;
import java.net.UnknownHostException;

/** Class ServerProxy provides methods which are specifically defined for
 *  the case UsaProxy is used on a server itself
 */
public class ServerProxy implements ProxyType {
	
    //private InetAddress		serverAddress;
    private InetAddress 	hostAddress;
	private int 			serverPort;						  /** server port */
	
	/** Constructor, creates a ServerProxy with the given server information
	 *  and localhost as serverAddress.
	 * 
	 * @param hostAddress is the HTTP server address
	 * @param serverPort is the port of the web server
     */
	public ServerProxy(InetAddress hostAddress, int serverPort) {
		super();
		this.serverPort 	= serverPort;
		this.hostAddress	= hostAddress;
		/*try {
			this.serverAddress  = java.net.InetAddress.getLocalHost();
		} catch (UnknownHostException e1) {
	    	System.err.println("\nAn ERROR occured while defining serverAddress: " + e1 );
		}*/
	}
	
	/**
     *  Returns a Socket of the web server.
     *  
     *  @return the Socket
     */
	public Socket getServerConnect() throws Exception {
		return new Socket(hostAddress.getHostName(),serverPort);
	}
	
	/**
     *  Returns the request line.
     *  <br><br>
     *  The URL is reduced to a relative file path. HTTP version 1.0 is added.
     *  
     *  @param method is the request method
     *  @param url is the requested URL
     *  @return the request String
     */
	public String getRequestLine(String method, URL url) {
		return method + " " + url.getFile() + " HTTP/1.0";
	}
	
	/**
     *  Returns the script String in the form of a script tag with the proxyscript.js as src attribute.
     *  The HTTP server address is used as host.
     *  
     *  @return the script String
     */
	public String getScriptString() {
		return "<script src='http://" + hostAddress.getHostName() + "/usaproxylolo/proxyscript.js' type='text/javascript'></script>";
	}

	/** not implemented by ServerProxy */
	public void setRequestURL(URL url) {}
	
	/**
	 * Returns the host name
	 * @return a host name String
	 */
	public String getHostName() { return this.hostAddress.getHostName(); }

}
